import React, { useState } from "react";
import { FormControl, FormHelperText, withStyles } from "@material-ui/core";
import clsx from "clsx";
import ColorPicker from "material-ui-color-picker";
import { getErrorMessages, getErrorsForPointer } from "../EditorErrorMessages";
export var styles = {
    root: {
        width: "100%"
    },
    input: {
        color: "rgba(0, 0, 0, 0.87)"
    }
};
var EditorColorField = function (props) {
    var schema = props.schema, value = props.value, readonly = props.readonly, required = props.required, disabled = props.disabled, onChange = props.onChange, classes = props.classes, pointer = props.pointer, errorReport = props.errorReport, registry = props.registry;
    var _a = useState(schema.default || value || ""), localValue = _a[0], setValue = _a[1];
    var handleChange = React.useCallback(function (newValue) {
        if (newValue === "") {
            newValue = undefined;
        }
        if (onChange) {
            setValue(newValue);
            onChange(newValue);
        }
    }, [onChange]);
    var errors = getErrorsForPointer(pointer, errorReport);
    var errorMessages = getErrorMessages(schema, errors, registry);
    return (React.createElement(FormControl, { className: classes.root },
        React.createElement(ColorPicker, { name: "color", defaultValue: localValue, value: localValue, autoComplete: "off", label: schema.title || "", disabled: disabled, required: required, inputProps: {
                readOnly: readonly,
                "aria-label": schema.description || "",
                value: localValue || "",
                className: clsx(classes.input)
            }, error: errorMessages.length > 0, onChange: handleChange }),
        React.createElement(FormHelperText, { error: errorMessages.length > 0 }, errorMessages.length ? errorMessages[0] : schema.description)));
};
export default withStyles(styles, { name: "DcEditorColorField" })(EditorColorField);
